@@ -21,7 +21,6 @@ from solid.solid_api import SolidAPI
 
 import httpx
 
-
 _HOST = os.environ.get("APP_HOST", "localhost")
 _SCHEME = os.environ.get("APP_SCHEME", "http")
 _PORT = os.environ.get("APP_PORT", "8069")
@@ -236,9 +235,17 @@ class SolidAPIWrapper(SolidAPI):
         """
         Use SolidAPI with authenticated client
         :param client_id: Client ID used to exchange for access token
+        :type client_id: str
         :param client_secret: Client secret used to exchange for access token
+        :type client_secret: str
         :param access_token: Access token used to access Solid data
+        :type access_token: dict
+        :param keypair: JWK key used by DPoP, can be JSON representation or JWK
+        :type keypair: jwcrypto.jwk.JWK | str
         """
+        assert all([client_id, client_secret, access_token, keypair]), "Required arguments: client_id, client_secret" \
+                                                                       "access_token, keypair"
+
         self.client_id = client_id
         self.client_secret = client_secret
         self.access_token = access_token
@@ -255,10 +262,15 @@ class SolidAPIWrapper(SolidAPI):
         scopes = ["openid", "offline_access"]
         token = {'access_token': access_token['access_token'],
                  'refresh_token': access_token.get('refresh_token'),
-                 'expires_at': time.time() + int(access_token['expires_in']),
                  'idp': client.idp,
                  'token_type': access_token['token_type'],
                  'scopes': scopes}
+
+        if 'expires_at' in access_token:
+            token['expires_at'] = access_token['expires_at']
+        else:
+            token['expires_at'] = time.time() + int(access_token['expires_in'])
+
         client._add_token(token)
 
         request_auth_client = OpenIDCClientAuther(client,
